A wrapper around [ggplot2::geom_point()] that uses a filled shape with a white centre by default.

grattan_point_filled(
  mapping = NULL,
  data = NULL,
  size = 3,
  stroke = 1.5,
  fill = "white",
  shape = 21,
  ...
)

Arguments

mapping

Set of aesthetic mappings created by [ggplot2::aes()]. If `NULL` (the default), inherits the plot mapping.

data

A data frame. If `NULL` (the default), inherits the plot data.

size

Size of the point

stroke

width of the line around the outside of the point

fill

The colour on the inside of the point

shape

The shape of the point; default is 21. See `vignette("ggplot2-specs")` under `Point` for more about this.

...

arguments passed to [ggplot2::geom_point()]

Examples

library(ggplot2)
ggplot(mtcars, aes(x = wt, y = mpg, col = factor(cyl))) +
  grattantheme::grattan_point_filled()